=== modified file 'drizzled/common_includes.h'
--- drizzled/common_includes.h	2008-11-17 07:23:53 +0000
+++ drizzled/common_includes.h	2008-11-17 23:20:25 +0000
@@ -38,19 +38,22 @@
 
 /* Cross-platform portability code and standard includes */
 #include <drizzled/global.h>
+/* Contains system-wide constants and #defines */
+#include <drizzled/definitions.h>
+/* System-wide common data structures */
+#include <drizzled/structs.h>
+
 /* Lots of system-wide struct definitions like IO_CACHE,
    prototypes for all my_* functions */
 #include <mysys/my_sys.h>
 /* Custom C string functions */
 #include <mystrings/m_string.h>
 /* Defines for the storage engine handler -- i.e. HA_XXX defines */
-#include <drizzled/base.h>			                /* Needed by field.h */
+/* Needed by field.h */
+#include <drizzled/base.h>
+
 /* The <strong>INTERNAL</strong> plugin API - not the external, or public, server plugin API */
-#include "sql_plugin.h"
-/* Contains system-wide constants and #defines */
-#include <drizzled/definitions.h>
-/* System-wide common data structures */
-#include <drizzled/structs.h>
+#include <drizzled/sql_plugin.h>
 
 
 /**
@@ -73,10 +76,6 @@
 #define current_session _current_session()
 
 
-/* Drizzle server data type class definitions */
-#include <drizzled/field.h>
-
-
 #include <drizzled/sql_class.h>
 
 

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2008-11-17 07:23:53 +0000
+++ drizzled/item.cc	2008-11-17 23:20:25 +0000
@@ -358,6 +358,12 @@
 }
 
 
+int Item::decimal_int_part() const
+{
+  return my_decimal_int_part(decimal_precision(), decimals);
+}
+
+
 void Item::print(String *str, enum_query_type)
 {
   str->append(full_name());
@@ -1265,6 +1271,31 @@
   tmp_field->decimals= field->decimals();
 }
 
+
+double Item_ident_for_show::val_real()
+{
+  return field->val_real();
+}
+
+
+int64_t Item_ident_for_show::val_int()
+{
+  return field->val_int();
+}
+
+
+String *Item_ident_for_show::val_str(String *str)
+{
+  return field->val_str(str);
+}
+
+
+my_decimal *Item_ident_for_show::val_decimal(my_decimal *dec)
+{
+  return field->val_decimal(dec);
+}
+
+
 /**********************************************/
 
 Item_field::Item_field(Field *f)
@@ -1599,6 +1630,24 @@
 }
 
 
+enum Item_result Item_field::result_type () const
+{
+  return field->result_type();
+}
+
+
+Item_result Item_field::cast_to_int_type() const
+{
+  return field->cast_to_int_type();
+}
+
+
+enum_field_types Item_field::field_type() const
+{
+  return field->type();
+}
+
+
 void Item_field::fix_after_pullout(st_select_lex *new_parent, Item **)
 {
   if (new_parent == depended_from)
@@ -1612,6 +1661,12 @@
 }
 
 
+bool Item_field::is_null()
+{
+  return field->is_null();
+}
+
+
 Item *Item_field::get_tmp_table_item(Session *session)
 {
   Item_field *new_item= new Item_field(session, this);
@@ -3572,6 +3627,13 @@
   return;
 }
 
+
+bool Item_field::result_as_int64_t()
+{
+  return field->can_be_compared_as_int64_t();
+}
+
+
 /**
   Find a field among specified multiple equalities.
 
@@ -3757,6 +3819,12 @@
 }
 
 
+uint32_t Item_field::max_disp_length()
+{
+  return field->max_display_length();
+}
+
+
 void Item::init_make_field(Send_field *tmp_field,
 			   enum enum_field_types field_type_arg)
 {
@@ -5722,6 +5790,12 @@
 }
 
 
+bool Item_cache::eq_def(Field *field)
+{
+  return cached_field ? cached_field->eq_def (field) : false;
+}
+
+
 void Item_cache_int::store(Item *item)
 {
   value= item->val_int_result();
@@ -5823,6 +5897,14 @@
 }
 
 
+Item_cache_str::Item_cache_str(const Item *item) :
+  Item_cache(), value(0),
+  is_varbinary(item->type() == FIELD_ITEM &&
+               ((const Item_field *) item)->field->type() ==
+               DRIZZLE_TYPE_VARCHAR &&
+               !((const Item_field *) item)->field->has_charset())
+{}
+
 void Item_cache_str::store(Item *item)
 {
   value_buff.set(buffer, sizeof(buffer), item->collation.collation);

=== modified file 'drizzled/item.h'
--- drizzled/item.h	2008-11-17 04:11:21 +0000
+++ drizzled/item.h	2008-11-17 23:20:25 +0000
@@ -21,6 +21,8 @@
 #define DRIZZLED_ITEM_H
 
 #include <drizzled/dtcollation.h>
+#include <mysys/drizzle_time.h>
+#include <drizzled/my_decimal.h>
 
 class Protocol;
 class TableList;
@@ -32,7 +34,7 @@
 class user_var_entry;
 class Item_sum;
 class Item_in_subselect;
-
+class Send_field;
 
 void item_init(void);			/* Init item functions */
 
@@ -385,8 +387,8 @@
   inline uint32_t float_length(uint32_t decimals_par) const
   { return decimals != NOT_FIXED_DEC ? (DBL_DIG+2+decimals_par) : DBL_DIG+8;}
   virtual uint32_t decimal_precision() const;
-  inline int decimal_int_part() const
-  { return my_decimal_int_part(decimal_precision(), decimals); }
+  int decimal_int_part() const;
+
   /*
     Returns true if this is constant (during query execution, i.e. its value
     will not change until next fix_fields) and its value is known.
@@ -682,10 +684,10 @@
   {}
 
   enum Type type() const { return FIELD_ITEM; }
-  double val_real() { return field->val_real(); }
-  int64_t val_int() { return field->val_int(); }
-  String *val_str(String *str) { return field->val_str(str); }
-  my_decimal *val_decimal(my_decimal *dec) { return field->val_decimal(dec); }
+  double val_real();
+  int64_t val_int();
+  String *val_str(String *str);
+  my_decimal *val_decimal(my_decimal *dec);
   void make_field(Send_field *tmp_field);
 };
 
@@ -743,18 +745,9 @@
   int save_in_field(Field *field,bool no_conversions);
   void save_org_in_field(Field *field);
   table_map used_tables() const;
-  enum Item_result result_type () const
-  {
-    return field->result_type();
-  }
-  Item_result cast_to_int_type() const
-  {
-    return field->cast_to_int_type();
-  }
-  enum_field_types field_type() const
-  {
-    return field->type();
-  }
+  enum Item_result result_type () const;
+  Item_result cast_to_int_type() const;
+  enum_field_types field_type() const;
   enum_monotonicity_info get_monotonicity_info() const
   {
     return MONOTONIC_STRICT_INCREASING;
@@ -765,7 +758,7 @@
   bool get_date(DRIZZLE_TIME *ltime,uint32_t fuzzydate);
   bool get_date_result(DRIZZLE_TIME *ltime,uint32_t fuzzydate);
   bool get_time(DRIZZLE_TIME *ltime);
-  bool is_null() { return field->is_null(); }
+  bool is_null();
   void update_null_value();
   Item *get_tmp_table_item(Session *session);
   bool collect_item_field_processor(unsigned char * arg);
@@ -775,16 +768,13 @@
   bool check_vcol_func_processor(unsigned char *arg __attribute__((unused)))
   { return false; }
   void cleanup();
-  bool result_as_int64_t()
-  {
-    return field->can_be_compared_as_int64_t();
-  }
+  bool result_as_int64_t();
   Item_equal *find_item_equal(COND_EQUAL *cond_equal);
   bool subst_argument_checker(unsigned char **arg);
   Item *equal_fields_propagator(unsigned char *arg);
   bool set_no_const_sub(unsigned char *arg);
   Item *replace_equal_field(unsigned char *arg);
-  inline uint32_t max_disp_length() { return field->max_display_length(); }
+  uint32_t max_disp_length();
   Item_field *filed_for_view_update() { return this; }
   Item *safe_charset_converter(const CHARSET_INFO * const tocs);
   int fix_outer_field(Session *session, Field **field, Item **reference);
@@ -1873,10 +1863,7 @@
   table_map used_tables() const { return used_table_map; }
   virtual void keep_array() {}
   virtual void print(String *str, enum_query_type query_type);
-  bool eq_def(Field *field) 
-  { 
-    return cached_field ? cached_field->eq_def (field) : false;
-  }
+  bool eq_def(Field *field);
   bool eq(const Item *item,
           bool binary_cmp __attribute__((unused))) const
   {
@@ -1943,13 +1930,7 @@
   bool is_varbinary;
 
 public:
-  Item_cache_str(const Item *item) :
-    Item_cache(), value(0),
-    is_varbinary(item->type() == FIELD_ITEM &&
-                 ((const Item_field *) item)->field->type() ==
-                   DRIZZLE_TYPE_VARCHAR &&
-                 !((const Item_field *) item)->field->has_charset())
-  {}
+  Item_cache_str(const Item *item);
   void store(Item *item);
   double val_real();
   int64_t val_int();

=== modified file 'drizzled/log.h'
--- drizzled/log.h	2008-11-17 07:23:53 +0000
+++ drizzled/log.h	2008-11-17 23:20:25 +0000
@@ -20,6 +20,7 @@
 #ifndef DRIZZLE_SERVER_LOG_H
 #define DRIZZLE_SERVER_LOG_H
 
+#include <drizzled/common.h>
 #include <mysys/iocache.h>
 #include <drizzled/xid.h>
 

=== modified file 'drizzled/opt_range.h'
--- drizzled/opt_range.h	2008-11-03 19:16:14 +0000
+++ drizzled/opt_range.h	2008-11-17 23:20:25 +0000
@@ -23,6 +23,7 @@
 #ifndef DRIZZLED_OPT_RANGE_H
 #define DRIZZLED_OPT_RANGE_H
 
+#include <drizzled/field.h>
 #include <mysys/queues.h>
 
 typedef struct st_key_part {

=== modified file 'drizzled/protocol.cc'
--- drizzled/protocol.cc	2008-10-23 02:48:56 +0000
+++ drizzled/protocol.cc	2008-11-17 23:20:25 +0000
@@ -630,6 +630,17 @@
 }
 
 
+bool Protocol::store(String *str)
+{
+  return store((char*) str->ptr(), str->length(), str->charset());
+}
+
+void Protocol::free()
+{
+  packet->free();
+}
+
+
 /****************************************************************************
   Functions to handle the simple (default) protocol where everything is
   This protocol is the one that is used by default between the MySQL server

=== modified file 'drizzled/protocol.h'
--- drizzled/protocol.h	2008-11-07 00:15:51 +0000
+++ drizzled/protocol.h	2008-11-17 23:20:25 +0000
@@ -20,10 +20,15 @@
 #ifndef DRIZZLED_PROTOCOL_H
 #define DRIZZLED_PROTOCOL_H
 
+#include <drizzled/sql_list.h>
+
+class String;
 class i_string;
 class Session;
+class my_decimal;
 typedef struct st_drizzle_field DRIZZLE_FIELD;
 typedef struct st_drizzle_rows DRIZZLE_ROWS;
+typedef struct st_drizzle_time DRIZZLE_TIME;
 
 class Protocol
 {
@@ -50,7 +55,7 @@
   bool store(I_List<i_string> *str_list);
   bool store(const char *from, const CHARSET_INFO * const cs);
   String *storage_packet() { return packet; }
-  inline void free() { packet->free(); }
+  void free();
   virtual bool write();
   inline  bool store(int from)
   { return store_long((int64_t) from); }
@@ -60,10 +65,9 @@
   { return store_int64_t((int64_t) from, 0); }
   inline  bool store(uint64_t from)
   { return store_int64_t((int64_t) from, 1); }
-  inline bool store(String *str)
-  { return store((char*) str->ptr(), str->length(), str->charset()); }
+  bool store(String *str);
 
-  virtual bool prepare_for_send(List<Item> *item_list) 
+  virtual bool prepare_for_send(List<Item> *item_list)
   {
     field_count=item_list->elements;
     return 0;
@@ -77,7 +81,7 @@
   virtual bool store_short(int64_t from)=0;
   virtual bool store_long(int64_t from)=0;
   virtual bool store_int64_t(int64_t from, bool unsigned_flag)=0;
-  virtual bool store_decimal(const my_decimal *)=0;
+  virtual bool store_decimal(const my_decimal * dec_value)=0;
   virtual bool store(const char *from, size_t length, const CHARSET_INFO * const cs)=0;
   virtual bool store(const char *from, size_t length, 
                      const CHARSET_INFO * const fromcs, const CHARSET_INFO * const tocs)=0;

=== modified file 'drizzled/sql_class.cc'
--- drizzled/sql_class.cc	2008-11-16 09:45:44 +0000
+++ drizzled/sql_class.cc	2008-11-17 23:20:25 +0000
@@ -2128,6 +2128,16 @@
   return;
 }
 
+void TMP_TABLE_PARAM::cleanup(void)
+{
+  /* Fix for Intel compiler */
+  if (copy_field)
+  {
+    delete [] copy_field;
+    save_copy_field= copy_field= 0;
+  }
+}
+
 
 void session_increment_bytes_sent(ulong length)
 {

=== modified file 'drizzled/sql_class.h'
--- drizzled/sql_class.h	2008-11-17 07:23:53 +0000
+++ drizzled/sql_class.h	2008-11-17 23:20:25 +0000
@@ -33,6 +33,7 @@
 #include <drizzled/ha_trx_info.h>
 #include <mysys/my_tree.h>
 #include <drizzled/handler.h>
+#include <drizzled/sql_error.h>
 
 class Relay_log_info;
 
@@ -42,6 +43,7 @@
 class Lex_input_stream;
 class Rows_log_event;
 class user_var_entry;
+class Copy_field;
 
 enum enum_enable_or_disable { LEAVE_AS_IS, ENABLE, DISABLE };
 enum enum_delay_key_write { DELAY_KEY_WRITE_NONE, DELAY_KEY_WRITE_ON,
@@ -2129,14 +2131,7 @@
     cleanup();
   }
   void init(void);
-  inline void cleanup(void)
-  {
-    if (copy_field)				/* Fix for Intel compiler */
-    {
-      delete [] copy_field;
-      save_copy_field= copy_field= 0;
-    }
-  }
+  void cleanup(void);
 };
 
 class select_union :public select_result_interceptor

=== modified file 'drizzled/sql_lex.h'
--- drizzled/sql_lex.h	2008-11-17 07:23:53 +0000
+++ drizzled/sql_lex.h	2008-11-17 23:20:25 +0000
@@ -30,6 +30,8 @@
 #include <drizzled/table_list.h>
 
 class select_result_interceptor;
+class virtual_column_info;
+
 /* YACC and LEX Definitions */
 
 /* These may not be declared yet */

=== modified file 'drizzled/structs.h'
--- drizzled/structs.h	2008-11-06 22:10:09 +0000
+++ drizzled/structs.h	2008-11-17 23:20:25 +0000
@@ -23,12 +23,13 @@
 #ifndef DRIZZLED_STRUCTS_H
 #define DRIZZLED_STRUCTS_H
 
-#include <mysys/iocache.h>
+#include <drizzled/base.h>
 #include <mysys/definitions.h>
 #include <drizzled/lex_string.h>
 
 class Table;
 class Field;
+typedef struct st_io_cache IO_CACHE;
 
 typedef struct st_date_time_format {
   unsigned char positions[8];

=== modified file 'mysys/iocache.h'
--- mysys/iocache.h	2008-10-07 02:23:06 +0000
+++ mysys/iocache.h	2008-11-17 23:20:25 +0000
@@ -21,6 +21,8 @@
 #ifndef mysys_iocache_h
 #define mysys_iocache_h
 
+#include <mysys/my_sys.h>
+
 #if defined(__cplusplus)
 extern "C" {
 #endif

=== modified file 'storage/archive/ha_archive.cc'
--- storage/archive/ha_archive.cc	2008-10-20 04:28:21 +0000
+++ storage/archive/ha_archive.cc	2008-11-17 23:20:25 +0000
@@ -15,6 +15,7 @@
 
 
 #include <drizzled/common_includes.h>
+#include <drizzled/field.h>
 #include <storage/myisam/myisam.h>
 
 #include "ha_archive.h"

=== modified file 'storage/csv/ha_tina.cc'
--- storage/csv/ha_tina.cc	2008-10-23 02:48:56 +0000
+++ storage/csv/ha_tina.cc	2008-11-17 23:20:25 +0000
@@ -41,6 +41,7 @@
  -Brian
 */
 #include <drizzled/common_includes.h>
+#include <drizzled/field.h>
 #include "ha_tina.h"
 #include <drizzled/error.h>
 

=== modified file 'storage/innobase/drizzle/ha_innodb.cc'
--- storage/innobase/drizzle/ha_innodb.cc	2008-11-16 09:45:44 +0000
+++ storage/innobase/drizzle/ha_innodb.cc	2008-11-17 23:20:25 +0000
@@ -31,6 +31,7 @@
 #include <drizzled/show.h>
 #include <drizzled/data_home.h>
 #include <drizzled/error.h>
+#include <drizzled/field.h>
 
 /* Include necessary InnoDB headers */
 extern "C" {

=== modified file 'storage/innobase/drizzle/handler0alter.cc'
--- storage/innobase/drizzle/handler0alter.cc	2008-10-29 21:21:57 +0000
+++ storage/innobase/drizzle/handler0alter.cc	2008-11-17 23:20:25 +0000
@@ -8,6 +8,7 @@
 # include <drizzled/common_includes.h>
 # include <drizzled/error.h>
 # include <mystrings/m_ctype.h>
+# include <drizzled/field.h>
 #else
 # include <mysql_priv.h>
 # include <mysqld_error.h>

=== modified file 'storage/innobase/drizzle/i_s.cc'
--- storage/innobase/drizzle/i_s.cc	2008-10-30 18:03:59 +0000
+++ storage/innobase/drizzle/i_s.cc	2008-11-17 23:20:25 +0000
@@ -14,6 +14,7 @@
 # include <mysys/hash.h>
 # include <mysys/mysys_err.h>
 # include <drizzled/plugin.h>
+# include <drizzled/field.h>
 #else
 # include <mysql_priv.h>
 # include <mysqld_error.h>

